@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: mplayer.pl,v 1.24 2006/03/30 18:53:14 khlut Exp $
+# $Id: mplayer.pl,v 1.26 2006/04/08 20:20:11 khlut Exp $
 # Bind mplayer and mencoder with HTML object
 # ElphelOgm is used to receive and record rtp mjpeg video
 #
@@ -124,50 +124,52 @@ sub url2mplayer {
     $v{href}=$v{baseURI}.'/'.$v{href}	if( $v{href}!~m|[a-zA-Z0-9]+:| );
     $v{href}=~s|^file://||;    
 }
-sub ifilt{
-    if($v{pause} || !$v{play}) {
-	$pausestate=1;
-	print SLVW "pause\n";
-	lock $queue;
-	$queue.="pause=1\nplay=0\n";
+sub cmd {
+    my ($c)=@_;
+    my ($var,$val) = split '=', $c, 2;
+    $val=~s/\n//;
+    if( $c eq "run=0\n" ) {
+        shut();
+        last;
+    }elsif( $var eq "pause" ) {
+        $val=0+$val;
+        $val=1 if $val!=0 && $val!=1 ;
+        if($val != $pausestate) {
+    	    $pausestate=$val;
+    	    print SLVW "pause\n";
+    	    lock $queue;
+    	    $queue.="pause=$val\nplay=".(1-$val)."\n";
+    }	    
+    }elsif( $var eq "filepos" ) {
+        if($val =~ s/%//) {
+    	    print SLVW "seek $val 1\n";
+        }else{
+	    print SLVW "seek $val 2\n";
+        }
+    }elsif( $var eq "framestep" ) {
+        print SLVW "frame_step\n";	    
+        $pausestate=1;
+        lock $queue;
+        $queue.="pause=1\nplay=0\n";
+    }elsif( $var eq "src" or $var eq "href") {
+        $v{href}=$val;
+        url2mplayer();
+        print SLVW "loadfile $v{href}\n";
+        lock $queue;
+        $queue.="$c";
+    }else{
+        $v{$var}=$val;
+        lock $queue;
+        $queue.="$c";
     }
+}
+sub ifilt{
+    
+    cmd("pause=1") 		    if $v{pause} || !$v{play};
+    cmd("filepos=$v{filepos}")      if $v{filepos};
+    cmd("framestep=$v{framestep}")  if $v{framestep};
     while(<STDIN>){
-	($var,$val)= split '=', $_, 2;
-	$val=~s/\n//;
-	if( $_ eq "run=0\n" ) {
-	    shut();
-	    last;
-	}elsif( $var eq "pause" ) {
-	    $val=0+$val;
-	    $val=1 if $val!=0 && $val!=1 ;
-	    if($val != $pausestate) {
-		$pausestate=$val;
-		print SLVW "pause\n";
-		lock $queue;
-		$queue.="pause=$val\nplay=".(1-$val)."\n";
-	    }	    
-	}elsif( $var eq "filepos" ) {
-	    if($val =~ s/%//) {
-		print SLVW "seek $val 1\n";
-	    }else{
-		print SLVW "seek $val 2\n";
-	    }
-	}elsif( $var eq "framestep" ) {
-	    print SLVW "frame_step\n";	    
-	    $pausestate=1;
-	    lock $queue;
-	    $queue.="pause=1\nplay=0\n";
-	}elsif( $var eq "src" or $var eq "href") {
-	    $v{href}=$val;
-	    url2mplayer();
-	    print SLVW "loadfile $v{href}\n";
-	    lock $queue;
-	    $queue.="$_";
-	}else{
-	    $v{$var}=$val;
-	    lock $queue;
-	    $queue.="$_";
-	}
+	cmd $_;
     }
 }
 
@@ -264,6 +266,11 @@ print "debug=1\n", # list of control variables
       
 while (<STDIN>){
     s/\n//;
+    if( $_ eq '.' ) {
+      if($v{href} && $v{autostart} !~ m/^(|0|false)$/i){  ##end of parameters marker
+	 $_="run=1";
+      }else{next;}
+    }
     if($_ !~ /.*=/){
 	print "error=1\n";
 	next;
@@ -272,11 +279,6 @@ while (<STDIN>){
     ($x,$y) = split '=', $_, 2;
     $x='href' if($x eq 'src' || $x eq 'SRC');
     $v{$x}=$y;
-    if( ($x eq 'href' && $v{autostart}  ||  $x eq 'autostart' && $v{href})  && $v{autostart} !~ m/^(|0|false)$/i){
-	$_="run=1";
-	$x="run";
-	$y="1";
-    }
     if("$_" eq "run=1"){
 	$OPTS="";
 	$v{baseURI}=~s|/[^/]*$||;
